@@ -1,21 +1,21 @@
 #!/bin/bash
 # PHP-5.2	(http://www.php.net)
-#	BuildScript for Plamo Linux 4.6
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-08-01
+#	BuildScript for Plamo Linux 4.7
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-09-18
 # require:
-HTTPD_VER=2.2.12
+HTTPD_VER=2.2.13
 HTTPD=httpd-$HTTPD_VER
-#	postgresql-8.3.x
+#	postgresql-8.4.x
 #	re2c-0.12.2
 #PHP
-VERSION=5.2.10
+VERSION=5.2.11
 #VERSION=5.2.7RC4
 #SUHOSIN
 # ex. http://download.suhosin.org/suhosin-0.9.27.tgz
-SUHOSIN=suhosin-0.9.27
-# ex. http://download.suhosin.org/suhosin-patch-5.2.7-0.9.6.3.patch.gz
+SUHOSIN=suhosin-0.9.29
+# ex. http://download.suhosin.org/suhosin-patch-5.2.x-0.9.x.patch.gz
 PAT_VER=
-#PAT_VER=0.9.6.3
+#PAT_VER=0.9.7
 DOC_ONLY=
 DOC_ONLY=-1	# -1: php binary package only
 #DOC_ONLY=1	# 1: document package only
@@ -37,14 +37,14 @@ fi
 #MBPAT_FILE=mbstring-jpr-25298-20050414.patch.diff.gz
 #MBPAT_URI=http://www.voltex.jp/patches/$MBPAT_FILE
 
-REL=P2
+REL=P1
 CPU=i586
 SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 SRC_DIR=$PLAMO/Archive/www/php
-PAC_DIR=$PLAMO/Packages/4.6/09_webdb/03_PHP.tgz/
-BUILD_DIR=$PLAMO/php52
+PAC_DIR=$PLAMO/Packages/4.7/09_webdb/03_PHP.tgz/
+BUILD_DIR=$PLAMO/php5
 CUSTOM_DIR=$BUILD_DIR/Custom
 # patch the following if suhosin patch is not applied.
 #CUSTOM_PAT=php-5.2.6-strict-session.patch
@@ -127,7 +127,7 @@ fi
 ./configure  --prefix=/$PREFIX --with-config-file-path=/$CONFIG \
   --with-apxs2=/opt/httpd/bin/apxs --with-pear \
   --enable-zend-multibyte --enable-mbstring --enable-mbregex \
-  --enable-exif --enable-soap --enable-sockets --enable-dbx --with-zlib \
+  --enable-exif --enable-soap --enable-sockets --with-zlib \
   --enable-sysvmsg --enable-sysvsem --enable-sysvshm --enable-shmop \
   --with-readline --enable-ftp --with-openssl \
   --with-pgsql  --with-pdo-pgsql=/opt/pgsql \
@@ -146,27 +146,27 @@ mkdir -p $WORK/opt/htdocs
 export PATH=/$PREFIX/bin:$PATH
 
 rm -rf /$PREFIX/lib/php/.channels/
-pear upgrade
+/$PREFIX/bin/pear upgrade
 
-pear install --alldeps DB
-pear install --alldeps Auth
-pear install --alldeps Auth_SASL
-pear install --alldeps HTML_Template_IT
-#pear install HTML_Common HTML_QuickForm HTML_QuickForm_Controller
-pear install --alldeps HTML_QuickForm HTML_QuickForm_Controller
-#pear install XML_Parser XML_Util Config
-pear install --alldeps Config
-pear install --alldeps MDB2
-pear install --alldeps Mail_Mime
-#pear install Net_Socket HTTP_Request
-pear install --alldeps HTTP_Request
-pear install --alldeps -f Net_URL
-pear install --alldeps -f SOAP
-# pear install Date Calendar
-pear install --alldeps -f Calendar
+/$PREFIX/bin/pear install --alldeps DB
+/$PREFIX/bin/pear install --alldeps Auth
+/$PREFIX/bin/pear install --alldeps Auth_SASL
+/$PREFIX/bin/pear install --alldeps HTML_Template_IT
+#/$PREFIX/bin/pear install HTML_Common HTML_QuickForm HTML_QuickForm_Controller
+/$PREFIX/bin/pear install --alldeps HTML_QuickForm HTML_QuickForm_Controller
+#/$PREFIX/bin/pear install XML_Parser XML_Util Config
+/$PREFIX/bin/pear install --alldeps Config
+/$PREFIX/bin/pear install --alldeps MDB2
+/$PREFIX/bin/pear install --alldeps Mail_Mime
+#/$PREFIX/bin/pear install Net_Socket HTTP_Request
+/$PREFIX/bin/pear install --alldeps HTTP_Request
+/$PREFIX/bin/pear install --alldeps -f Net_URL
+/$PREFIX/bin/pear install --alldeps -f SOAP
+# /$PREFIX/bin/pear install Date Calendar
+/$PREFIX/bin/pear install --alldeps -f Calendar
 
 
-pear upgrade-all
+/$PREFIX/bin/pear upgrade-all
 
 ZTS=`sh ./scripts/php-config --extension-dir`
 
@@ -549,7 +549,7 @@ cp -p /opt/$HTTPD/man/man1/*.1 opt/$HTTPD/man/man1/
 gzip opt/$HTTPD/man/man1/*.1
 
 cp -av $CUSTOM_DIR/htdocs/* $WORK/opt/htdocs/
-tar xvfz $CUSTOM_DIR/emacssl.tgz -C usr/share
+tar xvfz $CUSTOM_DIR/emacssl.tgz -C $WORK/usr/share
 curl -o $CUSTOM_DIR/php_browscap.ini http://browsers.garykeith.com/stream.asp\?PHP_BrowsCapINI
 cp $CUSTOM_DIR/php_browscap.ini $WORK/$PREFIX/lib/php/
 
